Changelog
=========
0.3.0
~~~~~

- Use new documentation on GitHub Pages

0.2.1
~~~~~

- Fix typo

0.2.0
~~~~~

- Update documentation
- Translate the documentation to Portuguese

0.1.0
~~~~~

- Start a new from Project from Django Stuff
